# pagure-importer
CLI tool for importing issues etc. from different sources like github to pagure

## How to run
1. Install it using ```pip``` . ```pip install pagure-importer```
2. Just answer what is asked, one by one.

### Present options for sources: github
### Present options for items: issues

### Tools used:
1. [libpagure](https://pagure.io/libpagure) - a python library for [pagure](https://pagure.io) api.
2. [PyGithub](https://github.com/PyGithub/PyGithub) - a python library for [github](https://github.com/) api.
